# Template PyPI package maker

Sets up a basic python package skeleton, including common package files and a minimal python package with a `logger` and a `utils` file.

## Usage

```
setup-pypi-package <package name>
```
